@@ -14,7 +14,7 @@ setMethod("addStepping",c("GenomicRanges"),function(obj, group.name, extend.size
     if(!is.null(group.name)){
       if(!group.selfish){
         x.n <- split(x, values(x)[,group.name])
-        irs <- unlist(range(ranges(x.n, ignore.strand = TRUE)))
+        irs <- unlist(range(ranges(x.n)))
         irs.new <- resize(irs, fix = fix, width = width(irs) + extend.size)
         irs.new <- sort(irs.new)
         .lvs <- disjointBins(irs.new)
